@@ -1,4 +1,4 @@
-from logging import Logger
+"""Network"""
 from typing import Optional
 from kameleoon.network.access_token_source_factory import AccessTokenSourceFactory
 from kameleoon.network.net_provider import NetProvider
@@ -6,6 +6,8 @@ from kameleoon.network.network_manager import NetworkManager
 
 
 class NetworkManagerFactory:
+    """Abstract network manager factory"""
+    # pylint: disable=R0913
     def create(
         self,
         site_code: str,
@@ -13,6 +15,6 @@ class NetworkManagerFactory:
         call_timeout: float,
         net_provider: NetProvider,
         access_token_source_factory: AccessTokenSourceFactory,
-        logger: Logger,
     ) -> NetworkManager:
+        """Creates and returns an instance of `NetworkManager` with the specified parameters."""
         raise NotImplementedError()
