@@ -19,7 +19,7 @@ class UrlProvider:
     DEFAULT_DATA_API_DOMAIN = "data.kameleoon.io"
     TEST_DATA_API_DOMAIN = "data.kameleoon.net"
     DEFAULT_AUTOMATION_API_DOMAIN = "api.kameleoon.com"
-    TEST_AUTOMATION_API_DOMAIN = "api.master.preview.kameleoon.net"
+    TEST_AUTOMATION_API_DOMAIN = "api.kameleoon.net"
 
     def __init__(
         self,
